#[non_exhaustive]pub enum SessionEnvironmentError {
AlreadyStarted,
AlreadyBound,
ProviderConflict,
Unavailable,
Workspace(WorkspaceError),
}Expand description
Why an Environment could not be fixed to a Session.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AlreadyStarted
The Session already started and its Environment can no longer change.
AlreadyBound
The Session is already bound to a different Environment.
ProviderConflict
The Environment’s workspace provider conflicts with the Agent configuration.
The recorded Environment or workspace head cannot be reopened.
Workspace(WorkspaceError)
The workspace provider rejected the requested operation.